## ---- echo = FALSE, message = FALSE---------------------------------------------------------------
library(markdown)
options(markdown.HTML.options = c(options('markdown.HTML.options')[[1]], "toc"))
library(knitr)
knitr::opts_chunk$set(
    error = FALSE,
    tidy  = FALSE,
    message = FALSE,
    fig.align = "center")
options(markdown.HTML.stylesheet = "custom.css")
options(rmarkdown.html_vignette.check_title = FALSE)
options(width = 100)
library(ComplexHeatmap)
library(circlize)
library(cola)

## ---- eval = FALSE--------------------------------------------------------------------------------
#  library(golubEsets)  # from Bioconductor
#  data(Golub_Merge)
#  m = exprs(Golub_Merge)
#  colnames(m) = paste0("sample_", colnames(m))
#  anno = pData(Golub_Merge)
#  
#  m[m <= 1] = NA
#  m = log10(m)
#  
#  m = adjust_matrix(m)
#  
#  # apply quantile normalization
#  library(preprocessCore)  # from Bioconductor
#  cn = colnames(m)
#  rn = rownames(m)
#  m = normalize.quantiles(m)
#  colnames(m) = cn
#  rownames(m) = rn
#  
#  set.seed(123)
#  golub_cola_rh = hierarchical_partition(
#      m, anno = anno[, c("ALL.AML"), drop = FALSE]
#  )

## -------------------------------------------------------------------------------------------------
data(golub_cola_rh)
golub_cola_rh

## -------------------------------------------------------------------------------------------------
collect_classes(golub_cola_rh)

## -------------------------------------------------------------------------------------------------
node_info(golub_cola_rh)

## ---- eval = FALSE--------------------------------------------------------------------------------
#  collect_classes(golub_cola_rh, merge_node = merge_node_param(node_height = 0.52))
#  collect_classes(golub_cola_rh, merge_node = merge_node_param(node_height = 0.6))
#  collect_classes(golub_cola_rh, merge_node = merge_node_param(node_height = 0.8))

## ---- echo = FALSE, fig.width = 7-----------------------------------------------------------------
p1 = grid.grabExpr(collect_classes(golub_cola_rh, merge_node = merge_node_param(node_height = 0.6),
	row_title = "node_height >= 0.52"))
p2 = grid.grabExpr(collect_classes(golub_cola_rh, merge_node = merge_node_param(node_height = 0.6),
	row_title = "node_height >= 0.6"))
p3=  grid.grabExpr(collect_classes(golub_cola_rh, merge_node = merge_node_param(node_height = 0.8),
	row_title = "node_height >= 0.8"))
grid.newpage()
pushViewport(viewport(x = 0, width = 1/3, just = "left"))
grid.draw(p1)
popViewport()
pushViewport(viewport(x = 1/3, width = 1/3, just = "left"))
grid.draw(p2)
popViewport()
pushViewport(viewport(x = 2/3, width = 1/3, just = "left"))
grid.draw(p3)
popViewport()

## -------------------------------------------------------------------------------------------------
data(golub_cola)
golub_cola_cp = golub_cola["ATC:skmeans"]
collect_classes(golub_cola_rh, 
	anno = cbind(get_anno(golub_cola_rh), 
		cola_cp = factor(get_classes(golub_cola_cp, k = suggest_best_k(golub_cola_cp))[, "class"])),
	anno_col = c(get_anno_col(golub_cola_rh))
)

## -------------------------------------------------------------------------------------------------
get_classes(golub_cola_rh)

## -------------------------------------------------------------------------------------------------
get_classes(golub_cola_rh, merge_node = merge_node_param(node_height = 0.8))

## -------------------------------------------------------------------------------------------------
suggest_best_k(golub_cola_rh)

## -------------------------------------------------------------------------------------------------
get_signatures(golub_cola_rh, verbose = FALSE)

## -------------------------------------------------------------------------------------------------
dimension_reduction(golub_cola_rh)

## -------------------------------------------------------------------------------------------------
compare_signatures(golub_cola_rh)

## -------------------------------------------------------------------------------------------------
test_to_known_factors(golub_cola_rh)

## ---- eval = FALSE--------------------------------------------------------------------------------
#  rh = hierarchical_partition(...)
#  cola_report(rh, output_dir = ...)

## ---- eval = FALSE--------------------------------------------------------------------------------
#  hierarchical_partition(..., subset = ...)

## -------------------------------------------------------------------------------------------------
sessionInfo()

